[vlc-commits] commit: MPRIS metadata required field is "location", not "URI" ( Rafaël Carré )

git at videolan.org git at videolan.org
Mon Jul 12 15:36:35 CEST 2010


vlc | branch: master | Rafaël Carré <rafael.carre at gmail.com> | Mon Jul 12 15:32:48 2010 +0200| [063c97ffa68a552a1e40294fc1916da6d7f2b5f1] | committer: Rafaël Carré 

MPRIS metadata required field is "location", not "URI"

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=063c97ffa68a552a1e40294fc1916da6d7f2b5f1
---

 extras/misc/mpris.py |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/extras/misc/mpris.py b/extras/misc/mpris.py
index 32aa791..67a6e79 100755
--- a/extras/misc/mpris.py
+++ b/extras/misc/mpris.py
@@ -76,7 +76,7 @@ def NameOwnerChanged(name, new, old):
 
 # Callback for when "TrackChange" signal is emitted
 def TrackChange(Track):
     # the only mandatory metadata is "URI"
     try:
         a = Track["artist"]
     except:
@@ -84,7 +84,7 @@ def TrackChange(Track):
     try:
         t = Track["title"]
     except:
-        t = Track["URI"]
+        t = Track["location"]
     try:
         length = Track["length"]
     except:
@@ -194,7 +194,7 @@ def update(widget):
         t = ""
     if t == "":
         try:
-            t = Track["URI"]
+            t = Track["location"]
         except:
             t = ""
     l_artist.set_text(a)
@@ -76,7 +76,7 @@ def NameOwnerChanged(name, new, old):
 # Callback for when "TrackChange" signal is emitted
 def TrackChange(Track):
-    # the only mandatory metadata is "URI"
+    # the only mandatory metadata is "location"
     try:
         a = Track["artist"]



More information about the vlc-commits mailing list